@@ -1,8 +1,16 @@
-# $Id: twitter.py 1044 2014-09-22 23:48:20Z mwall $
+# $Id: twitter.py 1052 2014-10-14 20:11:46Z mwall $
 # Copyright 2014 Matthew Wall
 """
 Tweet weather data
 
+You must first obtain app and oauth credentials in order to tweet.  See the
+twitter developer documentation to obtain these:
+
+  https://dev.twitter.com/oauth/overview
+
+Specifically, you will need four things:  app_key, app_key_secret, oauth_token,
+and oauth_token_secret.
+
 Installation:
 
 0) install twython
@@ -28,6 +36,16 @@ Installation:
 3) restart weewx
     sudo /etc/init.d/weewx stop
     sudo /etc/init.d/weewx start
+
+By default, the units are those specified by the unit system in the
+StdConvert section of weewx.conf.  To specify a different unit system,
+use the unit_system option:
+
+[StdRESTful]
+    [[Twitter]]
+        unit_system = METRICWX
+
+Possible values include US, METRIC, or METRICWX.
 """
 
 import Queue
@@ -37,10 +55,11 @@ import time
 
 import weewx
 import weewx.restx
+import weewx.units
 
 from twython import Twython, TwythonError, TwythonAuthError, TwythonRateLimitError
 
-VERSION = "0.3"
+VERSION = "0.4"
 
 def logmsg(level, msg):
     syslog.syslog(level, 'restx: Twitter: %s' % msg)
@@ -60,9 +79,26 @@ def _format(label, fmt, datum):
 
 class Twitter(weewx.restx.StdRESTbase):
     def __init__(self, engine, config_dict):
+        """Initialize for posting to twitter.  This service supports the
+        standard restful options plus the following:
+
+        Required parameters:
+
+        station: a short name to identify the weather station
+
+        twitter authentication credentials:
+        app_key
+        app_key_secret
+        oauth_token
+        oauth_token_secret
+
+        Optional parameters:
+
+        unit_system: one of US, METRIC, or METRICWX
+        Default is None
+        """
         super(Twitter, self).__init__(engine, config_dict)
-        d = config_dict.get('OWFSService', {})
-        self.binding = d.get('binding', 'archive')
+        loginf('service version is %s' % VERSION)
         try:
             site_dict = weewx.restx.get_dict(config_dict, 'Twitter')
             site_dict['station']
@@ -73,6 +109,16 @@ class Twitter(weewx.restx.StdRESTbase):
         except KeyError, e:
             logerr("Data will not be posted: Missing option %s" % e)
             return
+
+        # if a unit system was specified, get the weewx constant for it
+        usn = site_dict.get('unit_system', None)
+        if usn is not None:
+            site_dict['unit_system'] = weewx.units.unit_constants[usn]
+            loginf('units will be converted to %s' % usn)
+
+        # we can bind to archive or loop events, default to archive
+        self.binding = site_dict.get('binding', 'archive')
+
         self.loop_queue = Queue.Queue()
         self.loop_thread = TwitterThread(self.loop_queue, **site_dict)
         self.loop_thread.start()
@@ -80,7 +126,6 @@ class Twitter(weewx.restx.StdRESTbase):
             self.bind(weewx.NEW_LOOP_PACKET, self.handle_new_loop)
         else:
             self.bind(weewx.NEW_ARCHIVE_RECORD, self.handle_new_archive)
-        loginf('service version is %s' % VERSION)
         loginf('binding is %s' % self.binding)
         loginf("Data will be tweeted for %s" % site_dict['station'])
 
@@ -106,8 +151,9 @@ class TwitterThread(weewx.restx.RESTThread):
     def __init__(self, queue, 
                  station,
                  app_key, app_key_secret, oauth_token, oauth_token_secret,
+                 unit_system=None, 
                  log_success=True, log_failure=True,
-                 post_interval=300, max_backlog=sys.maxint, stale=None,
+                 post_interval=None, max_backlog=sys.maxint, stale=None,
                  timeout=60, max_tries=3, retry_wait=5):
         super(TwitterThread, self).__init__(queue,
                                             protocol_name='Twitter',
@@ -120,6 +166,7 @@ class TwitterThread(weewx.restx.RESTThread):
                                             max_tries=max_tries,
                                             timeout=timeout,
                                             retry_wait=retry_wait)
+        self.unit_system = unit_system
         self.station = station
         self.app_key = app_key
         self.app_key_secret = app_key_secret
@@ -127,6 +174,8 @@ class TwitterThread(weewx.restx.RESTThread):
         self.oauth_token_secret = oauth_token_secret
 
     def process_record(self, record, dummy_archive):
+        if self.unit_system is not None:
+            record = weewx.units.to_std_system(record, self.unit_system)
         s = []
         s.append("%s: ts: %s" % (self.station, record['dateTime']))
         for obs in self._FORMATS:
